#!/usr/bin/env python3

import subprocess
from astropy.time import Time

def main():

  date = '2006-11-07'
  datasetstr = 'TYC1886-01206-1'
  alpha = 94.47529405128425
  delta = 27.196950321273913
  prlx  = 2.130308688159737
  pmra  = 3.6407167052707883
  pmde  = -14.320419118801635
  epoch = 2457388.500789  # 2016.0
  offra = 0.0
  offde = 0.0

  f = open("kalliope.1000", "r")
  f2 = open("Occ.tmp", "w")

  f2.write('# t [TDB] & sigma_t & lambda WGS-84 [deg] & phi [deg] & alt [km] & contact [-1,0,1-4] & alpha Gaia-DR3 [deg] & delta [deg] & prlx [mas] & pmra [mas y^-1] & pmde [mas y^-1] & epoch [TDB] & offra [mas] & offde [mas] & dataset & datasetstr\n')

  dataset = 0
  for line in f.readlines():
    if line[0:1] == '#':
      continue
    l = line.split()

    lambda_ = float(l[7])
    phi = float(l[8])
    alt = float(l[9])/1.0e3

    DISAPP_TIME = l[17]
    DISAPP_EVENT_CODE = l[18]
    DISAPP_TIME_ACC = l[19]
    REAPP_TIME = l[22]
    REAPP_EVENT_CODE = l[23]
    REAPP_TIME_ACC = l[24]

    if DISAPP_EVENT_CODE == 'M':
      print("# LINE NOT USED:\n", line)
      continue
    if REAPP_EVENT_CODE == 'M':
      print("# LINE NOT USED:\n", line)
      continue

    sigma = 1.0  # sec; default

    if DISAPP_TIME_ACC == "-9.999":
      DISAPP_TIME_ACC = sigma
    if REAPP_TIME_ACC == "-9.999":
      REAPP_TIME_ACC = sigma

    dataset += 1

    t1 = Time(date + 'T' + DISAPP_TIME, scale='utc', format='isot')
    sigma_t1 = float(DISAPP_TIME_ACC)/86400.0
    t2 = Time(date + 'T' + REAPP_TIME, scale='utc', format='isot')
    sigma_t2 = float(REAPP_TIME_ACC)/86400.0

    f2.write("%.8f	%.6e	%.8f	%.8f	%.6f	%d	%.14f	%.14f	%.14f	%.14f	%.14f	%.8f	%.14f	%.14f	%d	%s\n" % (t1.tdb.jd, sigma_t1, lambda_, phi, alt, 1, alpha, delta, prlx, pmra, pmde, epoch, offra, offde, dataset, datasetstr))
    f2.write("%.8f	%.6e	%.8f	%.8f	%.6f	%d	%.14f	%.14f	%.14f	%.14f	%.14f	%.8f	%.14f	%.14f	%d	%s\n" % (t2.tdb.jd, sigma_t2, lambda_, phi, alt, 4, alpha, delta, prlx, pmra, pmde, epoch, offra, offde, dataset, datasetstr))
    
  f.close()
  f2.close()

  subprocess.check_output("sort -k1 -g < Occ.tmp > Occ.dat", shell=True)

if __name__ == "__main__":
  main()

